pub enum HistoryNavigationQuery {
Normal(LineBuffer),
PrefixSearch(String),
SubstringSearch(String),
}Expand description
Browsing modes for a History
Variants
Normal(LineBuffer)
bash style browsing through the history. Contained LineBuffer is used to store the state of manual entry before browsing through the history
PrefixSearch(String)
Search for entries starting with a particular string.
SubstringSearch(String)
Full exact search for all entries containing a string.