pub struct CwdAwareHinter { /* private fields */ }Expand description
A hinter that uses the completions or the history to show a hint to the user
Similar to fish autosuggestions
Implementations
Sourceimpl CwdAwareHinter
impl CwdAwareHinter
Sourcepub fn with_style(self, style: Style) -> Self
pub fn with_style(self, style: Style) -> Self
A builder that sets the style applied to the hint as part of the buffer
Sourcepub fn with_min_chars(self, min_chars: usize) -> Self
pub fn with_min_chars(self, min_chars: usize) -> Self
A builder that sets the number of characters that have to be present to enable history hints