pub struct HistoryItem<ExtraInfo: HistoryItemExtraInfo = IgnoreAllExtraInfo> {
pub id: Option<HistoryItemId>,
pub start_timestamp: Option<DateTime<Utc>>,
pub command_line: String,
pub session_id: Option<HistorySessionId>,
pub hostname: Option<String>,
pub cwd: Option<String>,
pub duration: Option<Duration>,
pub exit_status: Option<i64>,
pub more_info: Option<ExtraInfo>,
}Expand description
Represents one run command with some optional additional context
Fields
id: Option<HistoryItemId>primary key, unique across one history
start_timestamp: Option<DateTime<Utc>>date-time when this command was started
command_line: Stringthe full command line as text
session_id: Option<HistorySessionId>a unique id for one shell session. used so the history can be filtered to a single session
hostname: Option<String>the hostname the commands were run in
cwd: Option<String>the current working directory
duration: Option<Duration>the duration the command took to complete
exit_status: Option<i64>the exit status of the command
more_info: Option<ExtraInfo>arbitrary additional information that might be interesting NOTE: this attribute is required because of https://github.com/rust-lang/rust/issues/41617 (see https://github.com/serde-rs/serde/issues/1296#issuecomment-394056188 for the fix)
Implementations
Sourceimpl HistoryItem
impl HistoryItem
Sourcepub fn from_command_line(cmd: impl Into<String>) -> HistoryItem
pub fn from_command_line(cmd: impl Into<String>) -> HistoryItem
create a history item purely from the command line with everything else set to None